# -*- coding: utf-8 -*-

"""
BELA-dashboard sunshine module
"""

# This code is a part of belaweb system: https://github.com/letuananh/belaweb
# :developer: Le Tuan Anh <tuananh.ke@gmail.com>
# :license: MIT, see LICENSE for more details.

BELA_DASHBOARD_VERSION = '0.13.1'  # follow PEP-0440
BELA_DASHBOARD_BUILD = '2022-04-06'
__author__ = "Le Tuan Anh"
__email__ = "tuananh.ke@gmail.com"
__copyright__ = "Copyright (c) 2019, Le Tuan Anh <tuananh.ke@gmail.com>"
__credits__ = []
__license__ = "MIT License"
__description__ = ""
__url__ = "https://github.com/letuananh/belaweb"
__issue__ = "https://github.com/letuananh/belaweb/issues"
__source_code__ = __url__
__maintainer__ = "Le Tuan Anh"
__version_major__ = BELA_DASHBOARD_VERSION
__version__ = "{}a1".format(__version_major__)
__version_long__ = "{} - Alpha".format(__version_major__)
__status__ = "3 - Alpha"
