# -*- coding: utf-8 -*-

"""
BELA-dashboard sunshine module
"""

# This code is a part of belaweb system: https://github.com/letuananh/belaweb
# :developer: Le Tuan Anh <tuananh.ke@gmail.com>
# :license: MIT, see LICENSE for more details.

from .__version__ import BELA_DASHBOARD_VERSION
from .__version__ import BELA_DASHBOARD_BUILD
from .__version__ import __author__, __email__, __copyright__, __maintainer__
from .__version__ import __credits__, __license__, __description__, __url__
from .__version__ import __version_major__, __version_long__, __version__, __status__

__all__ = ['BELA_DASHBOARD_VERSION',
           'BELA_DASHBOARD_BUILD',
           "__version__", "__author__", "__description__", "__copyright__"]
